% This program replicates Figure 10 in "A Static Capital Buffer is 
% Hard to Beat" by Matthew Canzoneri, Behzad Diba, Luca Guerrieri 
% and Arsenii Mishin.

clear all

setpath_windows

global M_ oo_
global changes_names changes_vec



nperiods = 60;    % periods for IRFs
maxiter = 20;


% select shock and size
irfshock = char('eps_a');
shockssequence = -1;




% choose model files - these are the files for the case with regime
% switching
mod00 = 'model_safe_all_shocks';
mod11 = 'model_mixed_all_shocks';
mod10 = 'model_risky_all_shocks';
mod01 = 'model_spare_all_shocks';

% Under the Ramsey rule there is no switching
modnam2 = 'model_calibration';


% define the constraints

constraint1 = 'chi2_upper_bar+chi2_upper_bar_ss<0';    % If the Lagrange multiplier on the
% no-shorting constraints for risky
% loans is slack, it means that I want
% to make risky loans.
% Accordingly, go into 11 or 10

constraint_relax1 = '((l+l_ss)<0)|(l_upper_bar<0)'; % If it turns out that the quantity of
% risky loans is negative,  00
% notice that l is set to 0 in the 10
% file, therefore the first condition
% is irrelevant when transition back
% from 10, but it might be relevant
% when transition back from 11.


constraint2 = '((chi2_lower_bar<0)&(l_upper_bar>0))'; % If the Lagrange multiplier on the
% no-shorting constraints for risky
% loans  and on safe loans are both slack, it means that I want
% to make risky and safe loans. Go to
% 01 or 11, but since if this
% condition is met constraint1 will
% also be active, we can only go into
% 11. Hence, 01 is spare.

constraint_relax2 ='((l+l_ss)<0)|(l_upper_bar<0)';  % return to 10 or 00, but
% notice that
% constraint_relax1 is identical,
% therefore, if either
% condition is violated
% we will go back to 00


% end of inputs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% parameter changes

all_changes_vec = [0.001, 0.3, 0.5, 0.8, 1.1, 1.4, 1.6, 3.3, 7, 10, 100, 1000];
%all_changes_vec = [0.001, 1.1];
nchanges = length(all_changes_vec);

changes_names = char('phip_i','sigmap_d','gammap_increment');
changes_vec = [100,nan,0.001];

for this_change = 1:nchanges

changes_vec(2) = all_changes_vec(this_change);

[zdatalinear, zdatapiecewise, zdatass, oobase_, Mbase_, violvecbool ] = ...
    solve_two_constraints_add_violvecbool(mod00,mod10,mod01,mod11,...
    constraint1, constraint2,...
    constraint_relax1, constraint_relax2,...
    shockssequence,irfshock,nperiods,0,maxiter);

sigma_var_pos = strmatch('sigma',Mbase_.endo_names,'exact');
sigma_var_vec(this_change) = sum(zdatapiecewise(:,sigma_var_pos));

end

sigma_lower_bar = Mbase_.params(strmatch('sigma_lower_bar',Mbase_.param_names));
sigma_bar = Mbase_.params(strmatch('sigma_bar',Mbase_.param_names));

%% Plot

figure
plot(all_changes_vec,sigma_var_vec/(sigma_bar-sigma_lower_bar),'*')
title('Sensitivity analysis on the interest rate elasticity of deposits: responses to a 1 s.d. negative TFP shock with FIXED capital requirements');
xlabel('\sigma_d')
ylabel('Number of excessive risk-taking periods')
ylim([0 10])
xlim([0 10])




