% This program replicates Figures 8 and 9 in "A Static Capital Buffer is 
% Hard to Beat" by Matthew Canzoneri, Behzad Diba, Luca Guerrieri 
% and Arsenii Mishin.

clear all

setpath_windows

global M_ oo_
global changes_names changes_vec



nperiods = 60;    % periods for IRFs
maxiter = 20;


% select shock and size
irfshock = char('eps_a');
shockssequence = -1;




% choose model files - these are the files for the case with regime
% switching
mod00 = 'model_safe_all_shocks';
mod11 = 'model_mixed_all_shocks';
mod10 = 'model_risky_all_shocks';
mod01 = 'model_spare_all_shocks';

% Under the Ramsey rule there is no switching
modnam2 = 'model_calibration';


% define the constraints

constraint1 = 'chi2_upper_bar+chi2_upper_bar_ss<0';    % If the Lagrange multiplier on the
% no-shorting constraints for risky
% loans is slack, it means that I want
% to make risky loans.
% Accordingly, go into 11 or 10

constraint_relax1 = '((l+l_ss)<0)|(l_upper_bar<0)'; % If it turns out that the quantity of
% risky loans is negative,  00
% notice that l is set to 0 in the 10
% file, therefore the first condition
% is irrelevant when transition back
% from 10, but it might be relevant
% when transition back from 11.


constraint2 = '((chi2_lower_bar<0)&(l_upper_bar>0))'; % If the Lagrange multiplier on the
% no-shorting constraints for risky
% loans  and on safe loans are both slack, it means that I want
% to make risky and safe loans. Go to
% 01 or 11, but since if this
% condition is met constraint1 will
% also be active, we can only go into
% 11. Hence, 01 is spare.

constraint_relax2 ='((l+l_ss)<0)|(l_upper_bar<0)';  % return to 10 or 00, but
% notice that
% constraint_relax1 is identical,
% therefore, if either
% condition is violated
% we will go back to 00


% end of inputs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% parameter changes
changes_names = char('phip_i','sigmap_d','gammap_increment');
changes_vec = [100,1.1,0.001];



[zdatalinear, zdatapiecewise, zdatass, oobase_, Mbase_, violvecbool ] = ...
    solve_two_constraints_add_violvecbool(mod00,mod10,mod01,mod11,...
    constraint1, constraint2,...
    constraint_relax1, constraint_relax2,...
    shockssequence,irfshock,nperiods,0,maxiter);

% parameter changes
changes_names = char('phip_i','sigmap_d','gammap_increment');
changes_vec = [100,0.001,0.001];


[zdatalinear2, zdatapiecewise2, zdatass2, oobase2_, Mbase2_, violvecbool2 ] = ...
    solve_two_constraints_add_violvecbool(mod00,mod10,mod01,mod11,...
    constraint1, constraint2,...
    constraint_relax1, constraint_relax2,...
    shockssequence,irfshock,nperiods,0,maxiter);


% repeat the simulation for the model with endogenous capital requirements

% % set the static buffer to 0 when using the optimal rule
% gammap_increment = 0;
% changes_vec(end) = gammap_increment;
% 
% [zdatalinear2, zdatass2, oobase2_, Mbase2_ ] = ...
%     solve_no_constraint(modnam2,...
%     shockssequence,irfshock,nperiods);


prefix1 = 's1_';
prefix2 = 's2_';
for this_var = 1:Mbase_.endo_nbr
    eval([prefix1,deblank(Mbase_.endo_names(this_var,:)),'_irf=zdatapiecewise(:,this_var);'])
    eval([prefix1,deblank(Mbase_.endo_names(this_var,:)),'_ss=zdatass(this_var);'])
    
    eval([prefix2,deblank(Mbase2_.endo_names(this_var,:)),'_irf=zdatapiecewise2(:,this_var);'])
    eval([prefix2,deblank(Mbase2_.endo_names(this_var,:)),'_ss=zdatass2(this_var);'])
    
end


%% Plots

titlelist = char('Total output', 'Bank capital requirement',...
    'Consumption', 'Credit/GDP ratio',...
    'Expected Equity Return Spread (risky-safe)',  'Total capital',...
    'Deposit rate spread','Investment Price' );


line1 = 100*[ s1_ytot_irf/s1_ytot_ss, s1_gamma_var_irf,...
    s1_c_irf/s1_c_ss, s1_ltot2ytot_irf/4,...
    [s1_r_e_upper_bar_irf(2:end)+s1_r_e_upper_bar_ss-s1_r_e_irf(2:end)-s1_r_e_ss; nan], s1_ktot_irf/s1_ktot_ss,...
    [s1_r_e_irf(2:end)-s1_r_d_irf(1:end-1); nan],s1_q_irf ];

line2 = 100*[ s2_ytot_irf/s2_ytot_ss, s2_gamma_var_irf,...
    s2_c_irf/s2_c_ss, s2_ltot2ytot_irf/4,...
    [s2_r_e_upper_bar_irf(2:end)-s2_r_e_irf(2:end); nan], s2_ktot_irf/s2_ktot_ss,...
    [s2_r_e_irf(2:end)-s2_r_d_irf(1:end-1); nan],s2_q_irf ];


percent = 'Percent';
ppt = 'Perc. Point';
level = 'Level';
ylabels = char(percent,ppt,...
    percent,ppt,...
    ppt,percent,...
    ppt, percent);
figlabel = '';



legendlist  = char('Fixed Capital Requirements, \sigma_d=1.1','Fixed Capital Requirements \sigma_d =0.001');
makechart(titlelist,legendlist,figlabel,ylabels,line1,line2);

%% repeat for optimal capital rule


% parameter changes
changes_names = char('phip_i','sigmap_d','gammap_increment');
changes_vec = [100,1.1,0];


[zdatalinear, zdatass, oobase_, Mbase_ ] = ...
    solve_no_constraint(modnam2,...
    shockssequence,irfshock,nperiods);




% parameter changes
changes_names = char('phip_i','sigmap_d','gammap_increment');
changes_vec = [100,0.001,0];


[zdatalinear2, zdatass2, oobase2_, Mbase2_ ] = ...
    solve_no_constraint(modnam2,...
    shockssequence,irfshock,nperiods);


prefix1 = 's1_';
prefix2 = 's2_';
for this_var = 1:Mbase_.endo_nbr
    eval([prefix1,deblank(Mbase_.endo_names(this_var,:)),'_irf=zdatalinear(:,this_var);'])
    eval([prefix1,deblank(Mbase_.endo_names(this_var,:)),'_ss=zdatass(this_var);'])
    
    eval([prefix2,deblank(Mbase2_.endo_names(this_var,:)),'_irf=zdatalinear2(:,this_var);'])
    eval([prefix2,deblank(Mbase2_.endo_names(this_var,:)),'_ss=zdatass2(this_var);'])
    
end


%% Plots

titlelist = char('Total output', 'Bank capital requirement',...
    'Consumption', 'Credit/GDP ratio',...
    'Expected Equity Return Spread (risky-safe)',  'Total capital',...
    'Deposit rate spread','Investment Price' );


line1 = 100*[ s1_ytot_irf/s1_ytot_ss, s1_gamma_var_irf,...
    s1_c_irf/s1_c_ss, s1_ltot2ytot_irf/4,...
    [s1_r_e_upper_bar_irf(2:end)+s1_r_e_upper_bar_ss-s1_r_e_irf(2:end)-s1_r_e_ss; nan], s1_ktot_irf/s1_ktot_ss,...
    [s1_r_e_irf(2:end)-s1_r_d_irf(1:end-1); nan],s1_q_irf ];

line2 = 100*[ s2_ytot_irf/s2_ytot_ss, s2_gamma_var_irf,...
    s2_c_irf/s2_c_ss, s2_ltot2ytot_irf/4,...
    [s2_r_e_upper_bar_irf(2:end)-s2_r_e_irf(2:end); nan], s2_ktot_irf/s2_ktot_ss,...
    [s2_r_e_irf(2:end)-s2_r_d_irf(1:end-1); nan],s2_q_irf ];


percent = 'Percent';
ppt = 'Perc. Point';
level = 'Level';
ylabels = char(percent,ppt,...
    percent,ppt,...
    ppt,percent,...
    ppt, percent);
figlabel = '';



legendlist  = char('Optimal Capital Requirements, \sigma_d=1.1','Optimal Capital Requirements \sigma_d =0.001');
makechart(titlelist,legendlist,figlabel,ylabels,line1,line2);